==> crates-0.0.5.tgz: package/cli.js <==
#!/usr/bin/env node
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var prog = require('caporal');
// eslint-disable-next-line import/no-extraneous-dependencies
var glob = require('glob');

var generator = require('./generator').default;

prog.version('0.0.2').help('A dynamic library to internationalize your things.').command('create', 'Create translations files.').option('-g, --glob <pattern>', 'Search pattern to create the translations files.', null, '**/*.js').option('-l, --lang <languages>', 'Languages to translate.', prog.LIST).option('-e, --exclude <pattern>', 'Exclude files with pattern', null, 'node_modules|.git').action(function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(args, options, logger) {
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return glob(options.glob, { dot: true, ignore: options.exclude }, function () {
              var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(err, files) {
                return _regenerator2.default.wrap(function _callee$(_context) {
                  while (1) {
                    switch (_context.prev = _context.next) {
                      case 0:
                        if (!err) {
                          _context.next = 3;
                          break;
                        }

                        logger.info(err);
                        return _context.abrupt('return');

                      case 3:
                        _context.next = 5;
                        return generator(files, options.lang);

                      case 5:
                      case 'end':
                        return _context.stop();
                    }
                  }
                }, _callee, undefined);
              }));

              return function (_x4, _x5) {
                return _ref2.apply(this, arguments);
              };
            }());

          case 3:
            _context2.next = 8;
            break;

          case 5:
            _context2.prev = 5;
            _context2.t0 = _context2['catch'](0);

            console.error('CLI:', _context2.t0);

          case 8:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 5]]);
  }));

  return function (_x, _x2, _x3) {
    return _ref.apply(this, arguments);
  };
}());

prog.parse(process.argv);

==> crates-0.0.9.tgz: package/cli.js <==
#!/usr/bin/env node
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var prog = require('caporal');
// eslint-disable-next-line import/no-extraneous-dependencies
var glob = require('glob');

var generator = require('./generator').default;

prog.version('0.0.2').help('A dynamic library to internationalize your things.').command('create', 'Create translations files.').option('-g, --glob <pattern>', 'Search pattern to create the translations files.', null, '**/*.js').option('-l, --lang <languages>', 'Languages to translate.', prog.LIST).option('-e, --exclude <pattern>', 'Exclude files with pattern', prog.LIST, '**/node_modules/**,**/.git/**').action(function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(args, options, logger) {
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return glob(options.glob, { dot: true, ignore: options.exclude }, function () {
              var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(err, files) {
                return _regenerator2.default.wrap(function _callee$(_context) {
                  while (1) {
                    switch (_context.prev = _context.next) {
                      case 0:
                        if (!err) {
                          _context.next = 3;
                          break;
                        }

                        logger.info(err);
                        return _context.abrupt('return');

                      case 3:
                        _context.next = 5;
                        return generator(files, options.lang);

                      case 5:
                      case 'end':
                        return _context.stop();
                    }
                  }
                }, _callee, undefined);
              }));

              return function (_x4, _x5) {
                return _ref2.apply(this, arguments);
              };
            }());

          case 3:
            _context2.next = 8;
            break;

          case 5:
            _context2.prev = 5;
            _context2.t0 = _context2['catch'](0);

            console.error('CLI:', _context2.t0);

          case 8:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 5]]);
  }));

  return function (_x, _x2, _x3) {
    return _ref.apply(this, arguments);
  };
}());

prog.parse(process.argv);
